@@ -23,7 +23,7 @@ class BuildStack(Enum):
 class ExecutionStatus(Enum):
     success = 1
     error = 2
-    other = 3
+    aborted = 3
 
 
 @dataclass(frozen=True)
@@ -58,6 +58,7 @@ class BitriseBuild:
     workflow: str
     minutes: BuildMinutes
     status: ExecutionStatus
+    head_branch: str = None
 
 
 @dataclass(frozen=True)
@@ -68,6 +69,7 @@ class CrunchedNumbers:
     total: int
     successes: int = None
     failures: int = None
+    abortions: int = None
     credits: int = None
 
 
